@@ -655,36 +655,26 @@ GtkWidget *screenshooter_region_dialog_new (ScreenshotData *sd, gboolean plugin)
   GtkWidget *delay_spinner_box, *delay_spinner, *seconds_label;
 
   /* Create the dialog */
-  if (!plugin)
+  if (plugin)
     {
-      dlg =
-        xfce_titled_dialog_new_with_buttons (_("Screenshot"),
-                                             NULL,
-                                             GTK_DIALOG_DESTROY_WITH_PARENT,
-                                             "gtk-help",
-                                             GTK_RESPONSE_HELP,
-                                             "gtk-cancel",
-                                             GTK_RESPONSE_CANCEL,
-                                             "gtk-ok",
-                                             GTK_RESPONSE_OK,
-                                             NULL);
+      dlg = xfce_titled_dialog_new_with_mixed_buttons (_("Screenshot"),
+        NULL, GTK_DIALOG_DESTROY_WITH_PARENT,
+        "help-browser", _("_Help"), GTK_RESPONSE_HELP,
+        "window-close", _("_Close"), GTK_RESPONSE_OK,
+        NULL);
 
-      xfce_titled_dialog_set_subtitle (XFCE_TITLED_DIALOG (dlg), _("Take a screenshot"));
+      xfce_titled_dialog_set_subtitle (XFCE_TITLED_DIALOG (dlg), _("Preferences"));
     }
   else
     {
-      dlg =
-        xfce_titled_dialog_new_with_buttons (_("Screenshot"),
-                                             NULL,
-                                             GTK_DIALOG_DESTROY_WITH_PARENT,
-                                             "gtk-help",
-                                             GTK_RESPONSE_HELP,
-                                             "gtk-close",
-                                             GTK_RESPONSE_OK,
-                                             NULL);
+      dlg = xfce_titled_dialog_new_with_mixed_buttons (_("Screenshot"),
+        NULL, GTK_DIALOG_DESTROY_WITH_PARENT,
+        "help-browser", _("_Help"), GTK_RESPONSE_HELP,
+        "", _("_Cancel"), GTK_RESPONSE_CANCEL,
+        "", _("_OK"), GTK_RESPONSE_OK,
+        NULL);
 
-      xfce_titled_dialog_set_subtitle (XFCE_TITLED_DIALOG (dlg),
-                                       _("Preferences"));
+      xfce_titled_dialog_set_subtitle (XFCE_TITLED_DIALOG (dlg), _("Take a screenshot"));
     }
 
   gtk_window_set_position (GTK_WINDOW (dlg), GTK_WIN_POS_CENTER);
@@ -894,16 +884,12 @@ GtkWidget *screenshooter_actions_dialog_new (ScreenshotData *sd)
   GtkWidget *preview, *preview_ebox, *preview_box, *preview_label;
   GdkPixbuf *thumbnail;
 
-  dlg = xfce_titled_dialog_new_with_buttons (_("Screenshot"),
-                                             NULL,
-                                             GTK_DIALOG_DESTROY_WITH_PARENT,
-                                             "gtk-help",
-                                             GTK_RESPONSE_HELP,
-                                             "gtk-cancel",
-                                             GTK_RESPONSE_CANCEL,
-                                             "gtk-ok",
-                                             GTK_RESPONSE_OK,
-                                             NULL);
+  dlg = xfce_titled_dialog_new_with_mixed_buttons (_("Screenshot"),
+    NULL, GTK_DIALOG_DESTROY_WITH_PARENT,
+    "help-browser", _("_Help"), GTK_RESPONSE_HELP,
+    "", _("_Cancel"), GTK_RESPONSE_CANCEL,
+    "", _("_OK"), GTK_RESPONSE_OK,
+    NULL);
 
   xfce_titled_dialog_set_subtitle (XFCE_TITLED_DIALOG (dlg), _("Action"));
   gtk_window_set_position (GTK_WINDOW (dlg), GTK_WIN_POS_CENTER);
